@@ -1,7 +1,7 @@
 # ABSTRACT: Template toolkit engine for Dancer2
 
 package Dancer2::Template::TemplateToolkit;
-$Dancer2::Template::TemplateToolkit::VERSION = '0.205001';
+$Dancer2::Template::TemplateToolkit::VERSION = '0.205002';
 use Moo;
 use Carp qw<croak>;
 use Dancer2::Core::Types;
@@ -99,7 +99,7 @@ Dancer2::Template::TemplateToolkit - Template toolkit engine for Dancer2
 
 =head1 VERSION
 
-version 0.205001
+version 0.205002
 
 =head1 SYNOPSIS
 
@@ -146,6 +146,58 @@ or a reference to a string that contains the template.  The second arg
 is a hashref for the tokens that you wish to pass to
 L<Template::Toolkit> for rendering.
 
+=head1 ADVANCED CUSTOMIZATION
+
+L<Template>::Toolkit allows you to replace certain parts, like the internal
+STASH (L<Template::Stash>). In order to do that, one usually passes an object of another
+implementation such as L<Template::Stash::AutoEscaping> into the constructor.
+
+Unfortunately that is not possible when you configure L<Template>::Toolkit from
+your Dancer2 configuration file. You cannot instantiate a Perl object in a yaml file.
+Instead, you need to subclass this module, and use the subclass in your configuration file.
+
+A subclass to use the aforementioned L<Template::Stash::AutoEscaping> might look like this:
+
+    package Dancer2::Template::TemplateToolkit::AutoEscaping;
+    # or MyApp::
+    
+    use Moo;
+    use Template::Stash::AutoEscaping;
+    
+    extends 'Dancer2::Template::TemplateToolkit';
+    
+    around '_build_engine' => sub {
+        my $orig = shift;
+        my $self = shift;
+    
+        my $tt = $self->$orig(@_);
+    
+        # replace the stash object
+        $tt->service->context->{STASH} = Template::Stash::AutoEscaping->new(
+            $self->config->{STASH}
+        );
+    
+        return $tt;
+    };
+    
+    1;
+
+You can then use this new subclass in your config file instead of C<template_toolkit>.
+
+    # in config.yml
+    engines:
+      template:
+        TemplateToolkit::AutoEscaping:
+          start_tag: '<%'
+          end_tag:   '%>'
+          # optional arguments here
+          STASH:
+
+The same approach should work for SERVICE (L<Template::Service>), CONTEXT (L<Template::Context>),
+PARSER (L<Template::Parser>) and GRAMMAR (L<Template::Grammar>). If you intend to replace
+several of these components in your app, it is suggested to create an app-specific subclass
+that handles all of them at the same time.
+
 =head1 SEE ALSO
 
 L<Dancer2>, L<Dancer2::Core::Role::Template>, L<Template::Toolkit>.
